pub struct AsyncCanSocket<T: Socket>(/* private fields */);tokio only.Expand description
An asynchronous I/O wrapped CanSocket
Implementations
Sourceimpl AsyncCanSocket<CanSocket>
impl AsyncCanSocket<CanSocket>
Sourcepub async fn write_frame(&self, frame: CanFrame) -> IoResult<()>
pub async fn write_frame(&self, frame: CanFrame) -> IoResult<()>
Write a CAN frame to the socket asynchronously
Sourcepub fn try_write_frame(&self, frame: CanFrame) -> IoResult<()>
pub fn try_write_frame(&self, frame: CanFrame) -> IoResult<()>
Attempt to write a CAN frame to the socket without blocking.
Returns WouldBlock if the send buffer is full.
Bypasses the tokio readiness reactor: this call goes straight to
the underlying non-blocking fd, so no AsyncFd readiness event is
consumed. Mixing with write_frame on the same
socket is safe — the async path will simply re-check OS-level
readiness on its next poll and may briefly round-trip through
WouldBlock before re-arming.
Sourcepub async fn read_frame(&self) -> IoResult<CanFrame>
pub async fn read_frame(&self) -> IoResult<CanFrame>
Read a CAN frame from the socket asynchronously
Sourcepub fn try_read_frame(&self) -> IoResult<CanFrame>
pub fn try_read_frame(&self) -> IoResult<CanFrame>
Attempt to read a CAN frame from the socket without blocking.
Returns WouldBlock if no frame is immediately available.
Bypasses the tokio readiness reactor: this call goes straight to
the underlying non-blocking fd, so no AsyncFd readiness event is
consumed. Mixing with read_frame on the same
socket is safe — the async path will simply re-check OS-level
readiness on its next poll and may briefly round-trip through
WouldBlock before re-arming.
Sourcepub fn has_hw_timestamps(&self) -> bool
pub fn has_hw_timestamps(&self) -> bool
Returns true if the bound interface supports hardware receive timestamps.
Sourcepub async fn read_frame_with_timestamp(
&self,
) -> IoResult<(CanFrame, SystemTime)>
pub async fn read_frame_with_timestamp( &self, ) -> IoResult<(CanFrame, SystemTime)>
Read a CAN frame and its socket-layer arrival timestamp asynchronously.
Requires SocketOptions::set_recv_timestamp to be called first.
Sourcepub async fn read_frame_with_timestamps(
&self,
) -> IoResult<(CanFrame, CanTimestamps)>
pub async fn read_frame_with_timestamps( &self, ) -> IoResult<(CanFrame, CanTimestamps)>
Read a CAN frame and all available timestamps asynchronously.
Timestamp fields are None for modes not enabled on the socket.
Sourcepub async fn read_frame_with_hw_timestamp(
&self,
) -> IoResult<(CanFrame, Duration)>
pub async fn read_frame_with_hw_timestamp( &self, ) -> IoResult<(CanFrame, Duration)>
Read a CAN frame and its raw hardware clock timestamp asynchronously.
Requires SocketOptions::set_timestamping with
SOF_TIMESTAMPING_RX_HARDWARE | SOF_TIMESTAMPING_OPT_CMSG to be called first.
Sourceimpl AsyncCanSocket<CanFdSocket>
impl AsyncCanSocket<CanFdSocket>
Sourcepub async fn write_frame<F>(&self, frame: &F) -> IoResult<()>
pub async fn write_frame<F>(&self, frame: &F) -> IoResult<()>
Write a CAN FD frame to the socket asynchronously
Sourcepub fn try_write_frame<F>(&self, frame: &F) -> IoResult<()>
pub fn try_write_frame<F>(&self, frame: &F) -> IoResult<()>
Attempt to write a CAN frame to the socket without blocking.
Returns WouldBlock if the send buffer is full.
Bypasses the tokio readiness reactor: this call goes straight to
the underlying non-blocking fd, so no AsyncFd readiness event is
consumed. Mixing with write_frame on the same
socket is safe — the async path will simply re-check OS-level
readiness on its next poll and may briefly round-trip through
WouldBlock before re-arming.
Sourcepub async fn read_frame(&self) -> IoResult<CanAnyFrame>
pub async fn read_frame(&self) -> IoResult<CanAnyFrame>
Reads a CAN FD frame from the socket asynchronously
Sourcepub fn try_read_frame(&self) -> IoResult<CanAnyFrame>
pub fn try_read_frame(&self) -> IoResult<CanAnyFrame>
Attempt to read a CAN frame from the socket without blocking.
Returns WouldBlock if no frame is immediately available.
Bypasses the tokio readiness reactor: this call goes straight to
the underlying non-blocking fd, so no AsyncFd readiness event is
consumed. Mixing with read_frame on the same
socket is safe — the async path will simply re-check OS-level
readiness on its next poll and may briefly round-trip through
WouldBlock before re-arming.
Sourcepub fn has_hw_timestamps(&self) -> bool
pub fn has_hw_timestamps(&self) -> bool
Returns true if the bound interface supports hardware receive timestamps.
Sourcepub async fn read_frame_with_timestamp(
&self,
) -> IoResult<(CanAnyFrame, SystemTime)>
pub async fn read_frame_with_timestamp( &self, ) -> IoResult<(CanAnyFrame, SystemTime)>
Read a CAN frame and its socket-layer arrival timestamp asynchronously.
Requires SocketOptions::set_recv_timestamp to be called first.
Sourcepub async fn read_frame_with_timestamps(
&self,
) -> IoResult<(CanAnyFrame, CanTimestamps)>
pub async fn read_frame_with_timestamps( &self, ) -> IoResult<(CanAnyFrame, CanTimestamps)>
Read a CAN frame and all available timestamps asynchronously.
Timestamp fields are None for modes not enabled on the socket.
Sourcepub async fn read_frame_with_hw_timestamp(
&self,
) -> IoResult<(CanAnyFrame, Duration)>
pub async fn read_frame_with_hw_timestamp( &self, ) -> IoResult<(CanAnyFrame, Duration)>
Read a CAN frame and its raw hardware clock timestamp asynchronously.
Requires SocketOptions::set_timestamping with
SOF_TIMESTAMPING_RX_HARDWARE | SOF_TIMESTAMPING_OPT_CMSG to be called first.